@@ -1,7 +1,4 @@
-try:
-    from unittest.mock import MagicMock, create_autospec
-except ImportError:
-    from mock import create_autospec, MagicMock
+from unittest.mock import MagicMock
 
 import asyncio
 import time
@@ -191,7 +188,7 @@ def test_retry_call_with_fail_callback():
     except RuntimeError:
         pass
 
-    callback_mock.assert_called()
+    assert callback_mock.called
 
 
 def test_is_async():
